@@ -4,7 +4,7 @@
 # --------------------------------------------------------------------------------------------
 # pylint: disable=line-too-long
 
-__version__ = "2.29.2"
+__version__ = "2.33.1"
 
 import os
 import sys
@@ -65,7 +65,6 @@ class AzCli(CLI):
         from azure.cli.core.commands.transform import register_global_transforms
         from azure.cli.core._session import ACCOUNT, CONFIG, SESSION, INDEX, VERSIONS
         from azure.cli.core.util import handle_version_update
-        from azure.cli.core.commands.query_examples import register_global_query_examples_argument
 
         from knack.util import ensure_dir
 
@@ -89,7 +88,6 @@ class AzCli(CLI):
         self.local_context = AzCLILocalContext(self)
         register_global_transforms(self)
         register_global_subscription_argument(self)
-        register_global_query_examples_argument(self)
         register_ids_argument(self)  # global subscription must be registered first!
         register_cache_arguments(self)
 
@@ -107,7 +105,7 @@ class AzCli(CLI):
         self.data['headers']['x-ms-client-request-id'] = str(uuid.uuid1())
 
     def get_progress_controller(self, det=False, spinner=None):
-        import azure.cli.core.commands.progress as progress
+        from azure.cli.core.commands import progress
         if not self.progress_controller:
             self.progress_controller = progress.ProgressHook()
 
@@ -279,7 +277,7 @@ class MainCommandsLoader(CLICommandsLoader):
                 except Exception as ex:  # pylint: disable=broad-except
                     # Changing this error message requires updating CI script that checks for failed
                     # module loading.
-                    import azure.cli.core.telemetry as telemetry
+                    from azure.cli.core import telemetry
                     logger.error("Error loading command module '%s': %s", mod, ex)
                     telemetry.set_exception(exception=ex, fault_type='module-load-error-' + mod,
                                             summary='Error loading module: {}'.format(mod))
